# PyTorrentSearch

CLI + Python library to search for and parse magnet links from the Internet.

It leverages well known search engines such as Yandex, Google and DuckDuckGo. In my tests only Google was able to work reliably.

If you already have the website link you can just paste it as it would be a query then it will look for all magnet links that it can find in the raw HTML.

The idea is to quickly classify good sites and bad sites based on if the magnet link is already in the base HTML without having to load the JavaScript crap.

**DISCLAIMER**: Use at your own risk. This software doesn't store or provide illegal content by itself, it's only a search tool.
